@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.3.2.  */
+/* A Bison parser, made by GNU Bison 3.7.6.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -31,8 +31,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-/* Undocumented macros, especially those whose name start with YY_,
-   are private implementation details.  Do not rely on them.  */
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
 
 #ifndef YY_I386_I_PARSE_H_INCLUDED
 # define YY_I386_I_PARSE_H_INCLUDED
@@ -44,24 +45,33 @@
 extern int i386_debug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    kMASK = 258,
-    kPREFIX = 259,
-    kSUFFIX = 260,
-    kSYNONYM = 261,
-    kID = 262,
-    kNUMBER = 263,
-    kPERCPERC = 264,
-    kBITFIELD = 265,
-    kCHAR = 266,
-    kSPACE = 267
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    kMASK = 258,                   /* kMASK  */
+    kPREFIX = 259,                 /* kPREFIX  */
+    kSUFFIX = 260,                 /* kSUFFIX  */
+    kSYNONYM = 261,                /* kSYNONYM  */
+    kID = 262,                     /* kID  */
+    kNUMBER = 263,                 /* kNUMBER  */
+    kPERCPERC = 264,               /* kPERCPERC  */
+    kBITFIELD = 265,               /* kBITFIELD  */
+    kCHAR = 266,                   /* kCHAR  */
+    kSPACE = 267                   /* kSPACE  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define YYEMPTY -2
+#define YYEOF 0
+#define YYerror 256
+#define YYUNDEF 257
 #define kMASK 258
 #define kPREFIX 259
 #define kSUFFIX 260
@@ -75,10 +85,9 @@ extern int i386_debug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
 union YYSTYPE
 {
-#line 216 "i386_parse.y" /* yacc.c:1921  */
+#line 216 "i386_parse.y"
 
   unsigned long int num;
   char *str;
@@ -88,9 +97,9 @@ union YYSTYPE
   struct argname *name;
   struct argument *arg;
 
-#line 92 "i386_parse.h" /* yacc.c:1921  */
-};
+#line 101 "i386_parse.h"
 
+};
 typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
