@@ -1,5 +1,5 @@
 /* Check whether DIE has specific attribute, integrating DW_AT_abstract_origin.
-   Copyright (C) 2005 Red Hat, Inc.
+   Copyright (C) 2005, 2018 Red Hat, Inc.
    This file is part of elfutils.
 
    This file is free software; you can redistribute it and/or modify
@@ -37,7 +37,7 @@ int
 dwarf_hasattr_integrate (Dwarf_Die *die, unsigned int search_name)
 {
   Dwarf_Die die_mem;
-
+  int chain = 16; /* Largest DIE ref chain we will follow.  */
   do
     {
       if (INTUSE(dwarf_hasattr) (die, search_name))
@@ -53,7 +53,21 @@ dwarf_hasattr_integrate (Dwarf_Die *die, unsigned int search_name)
 
       die = INTUSE(dwarf_formref_die) (attr, &die_mem);
     }
-  while (die != NULL);
+  while (die != NULL && chain-- != 0);
+
+  /* Not NULL if it didn't have abstract_origin and specification
+     attributes.  If it is a split CU then see if the skeleton
+     has it.  */
+  if (die != NULL && is_cudie (die)
+      && die->cu->unit_type == DW_UT_split_compile)
+    {
+      Dwarf_CU *skel_cu = __libdw_find_split_unit (die->cu);
+      if (skel_cu != NULL)
+	{
+	  Dwarf_Die skel_die = CUDIE (skel_cu);
+	  return INTUSE(dwarf_hasattr) (&skel_die, search_name);
+	}
+    }
 
   return 0;
 }
