@@ -124,7 +124,7 @@ __libelf_compress (Elf_Scn *scn, size_t hsize, int ei_data,
   int flush = Z_NO_FLUSH;
   do
     {
-      /* Convert to raw if different endianess.  */
+      /* Convert to raw if different endianness.  */
       cdata = *data;
       bool convert = ei_data != MY_ELFDATA && data->d_size > 0;
       if (convert)
@@ -522,7 +522,7 @@ elf_compress (Elf_Scn *scn, int type, unsigned int flags)
 
       __libelf_reset_rawdata (scn, scn->zdata_base,
 			      scn->zdata_size, scn->zdata_align,
-			      __libelf_data_type (elf, sh_type,
+			      __libelf_data_type (&ehdr, sh_type,
 						  scn->zdata_align));
 
       return 1;
