@@ -1,5 +1,5 @@
 /* Return offset of first byte for the object.
-   Copyright (C) 1998, 2000, 2002 Red Hat, Inc.
+   Copyright (C) 1998, 2000, 2002, 2015 Red Hat, Inc.
    This file is part of elfutils.
    Written by Ulrich Drepper <drepper@redhat.com>, 1998.
 
@@ -37,9 +37,8 @@
 #include "libelfP.h"
 
 
-off_t
-elf_getbase (elf)
-     Elf *elf;
+int64_t
+elf_getbase (Elf *elf)
 {
-  return elf == NULL ? (off_t) -1 : elf->start_offset;
+  return elf == NULL ? (int64_t) -1 : elf->start_offset;
 }
