@@ -19,11 +19,11 @@
 #endif
 
 #include <errno.h>
-#include <error.h>
 #include <fcntl.h>
 #include <gelf.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include "system.h"
 
 int
 main (int argc, char *argv[])
